package org.javanicus.blog;

import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;
import java.awt.print.*;
import java.util.*;
import javax.swing.*;

public class BlogFrame extends JFrame
                            implements ActionListener, WindowListener {

  private JTabbedPane tabbedPane;
  private BlogPanel blogPanel;
  private BlogConfigPanel blogConfigPanel;
  private BlogOutPanel blogOutPanel;
  private BlogDestination destination = new BlogDestination();
  private Blogger blogger = new Blogger();

  public BlogFrame() {

    super("Blog Away...");

    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {
        dispose();
        System.exit(0);
      }
    });

    // set up the menu
    JMenuBar menuBar = createMenuBar();
    setJMenuBar(menuBar);

    JPanel content = new JPanel(new BorderLayout());

    tabbedPane = new JTabbedPane();

	blogPanel= new BlogPanel(destination);
    tabbedPane.addTab("Blog", blogPanel);

    blogConfigPanel = new BlogConfigPanel(destination);
    tabbedPane.addTab("Config", blogConfigPanel);

//    blogOutPanel = new BlogOutPanel();
//    tabbedPane.addTab("Output", blogOutPanel);


//    blogOutPanel.println("test1");
//    blogOutPanel.println("test2");
    content.add(tabbedPane);

    setContentPane(content);

  }

  /**
   * Handles menu selections by passing control to an appropriate method.
   */
  public void actionPerformed(ActionEvent event) {
    String command = event.getActionCommand();
    if (command.equals("Exit")) {
      attemptExit();
    } else if (command.equals("Create")) {
      blogger.createBlog(destination);
    } else if (command.equals("Blog")) {
      blogger.doIt(destination,blogPanel);
    } else if (command.equals("Upload")) {
      blogger.upload(destination);
    }

  }

  /**
   * Handles the user request to print.
   */

  /**
   * Creates and returns a menu-bar for the frame.
   */
  private JMenuBar createMenuBar() {

    // create the menus
    JMenuBar menuBar = new JMenuBar();

    // first the file menu
    JMenu fileMenu = new JMenu("File", true);
    fileMenu.setMnemonic('F');

    JMenuItem createItem = new JMenuItem("Create", 'c');
    createItem.setActionCommand("Create");
    createItem.addActionListener(this);
    fileMenu.add(createItem);

    JMenuItem blogItem = new JMenuItem("Blog", 'b');
    blogItem.setActionCommand("Blog");
    blogItem.addActionListener(this);
    fileMenu.add(blogItem);

    JMenuItem uploadItem = new JMenuItem("Upload", 'u');
    uploadItem.setActionCommand("Upload");
    uploadItem.addActionListener(this);
    fileMenu.add(uploadItem);

    fileMenu.add(new JSeparator());

    JMenuItem exitItem = new JMenuItem("Exit", 'x');
    exitItem.setActionCommand("Exit");
    exitItem.addActionListener(this);
    fileMenu.add(exitItem);


    // finally, glue together the menu and return it
    menuBar.add(fileMenu);
    return menuBar;

  }

  /**
   * Exits the application, but only if the user agrees.
   */
  private void attemptExit() {
    int result = JOptionPane.showConfirmDialog(this,
                   "Are you sure you want to exit?", "Confirmation...",
                   JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE);
    if (result==JOptionPane.YES_OPTION) {
      dispose();
      System.exit(0);
    }
  }


  /**
   * The starting point for the demonstration application.
   */
  public static void main(String[] args) {
    BlogFrame f = new BlogFrame();
    f.pack();

    centerFrameOnScreen(f);
    f.show();
  }


  public static void centerFrameOnScreen(JFrame frame) {

    Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
    Dimension f=frame.getSize();
    frame.setBounds(Math.max(0, (d.width - f.width) / 2),
                    Math.max(0, (d.height - f.height) / 2),
                    f.width, f.height);

  }


  /**
   * Clears the reference to the print preview frames when they are closed.
   */
  public void windowClosed(WindowEvent e) {
  }


  /**
   * Required for WindowListener interface, but not used by this class.
   */
  public void windowActivated(WindowEvent e) {}
  public void windowClosing(WindowEvent e) { }
  public void windowDeactivated(WindowEvent e) {}
  public void windowDeiconified(WindowEvent e) {}
  public void windowIconified(WindowEvent e) {}
  public void windowOpened(WindowEvent e) {}
}