package org.javanicus.blog;
import java.util.Properties;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;
import java.io.*;
import java.sql.*;

import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.VelocityEngine;


import com.oroinc.net.ftp.*;

public class Blogger implements BlogCallback {
	private String previousDate = "";
	private boolean firstItem = true;
	private Connection con = null;
    private BlogDestination destination = null;

	private  Connection getConnection() throws Exception{
		if (con == null) {
			Driver driver = (Driver)Class.forName("org.hsqldb.jdbcDriver").newInstance();
			Properties p = new Properties();
			p.put("user","sa");
			p.put("password","");
			String url = "jdbc:hsqldb:blog";
			con = driver.connect(url,p);
			con.setAutoCommit(true);
		}
		return con;
	}

	private  void store(BlogItem item) {
		try {
			Connection con = getConnection();
			PreparedStatement pstmt = con.prepareStatement("insert into item (blog_id,id,when,description) values (?,?,?,?)");
			pstmt.setString(1,destination.getProject());
			pstmt.setLong(2,item.getKey());
			pstmt.setTimestamp(3,new Timestamp(item.getDateValue().getTime()));
			pstmt.setString(4,item.getDescription());
			pstmt.executeUpdate();
			pstmt.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private  List readItems() {
		List rv = new ArrayList();
		try {
			Connection con = getConnection();
			Statement stmt = con.createStatement();
			ResultSet rs = stmt.executeQuery("select id,when,description from item where blog_id = 'javanicus' order by when desc");
			while (rs.next()) {
				long id = rs.getLong(1);
				Timestamp when = rs.getTimestamp(2);
				Date date = new Date(when.getTime());
				String description = rs.getString(3);

				rv.add(new BlogItem(id,date,description));
			}
			stmt.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return rv;
	}

	public BlogItem fetchBlogItemFromUser() {
		BlogItem testItem = new BlogItem(1,new Date(),"jdshkfjhs");
		return testItem;
	}

	public static void main(String[] args) {
		Blogger blogger = new Blogger();
		blogger.doIt(new BlogDestination(), blogger);
	}

	public void doIt(BlogDestination destination, BlogCallback callback) {
        this.destination = destination;
		BlogItem storableItem = callback.fetchBlogItemFromUser();
		if (storableItem != null) {
			store(storableItem);
		}
        createBlog(destination);
    }

    public void createBlog(BlogDestination destination) {
        this.destination = destination;
		try {
            PrintStream outT = new PrintStream(new FileOutputStream(destination.getProject() + "-blog.html"));
			doTemplate(outT,"template.vm");
			outT.close();

            PrintStream outX = new PrintStream(new FileOutputStream("rss.xml"));
			doTemplate(outX,"templateXML.vm");
			outX.close();

			con.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void doTemplate(PrintStream out,String templateFileName) throws Exception {
		// init
		VelocityEngine ve = new VelocityEngine();
		ve.init();
		VelocityContext context = new VelocityContext();
		Template t = ve.getTemplate( templateFileName );

	// data
		List items = readItems();
		context.put("destination",destination);
		context.put("items", items);

	// merge
		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out));
		t.merge( context, writer );
		writer.flush();

	// output
	//String s = writer.toString();
	}

	public void upload(BlogDestination destination) {
		this.destination = destination;
		String server   = destination.getServer();
		String username = destination.getUsername();
		String password = destination.getPassword();
		String remote   = destination.getRemote();
		String local    = destination.getLocal();

		FTPClient ftp = new FTPClient();
		ftp.addProtocolCommandListener(new PrintCommandListener(new PrintWriter(System.out)));

		try {
			int reply;
			ftp.connect(server);
			System.out.println("Connected to " + server + ".");
			reply = ftp.getReplyCode();
			if(!FTPReply.isPositiveCompletion(reply)) {
				ftp.disconnect();
				System.err.println("FTP server refused connection.");
				System.exit(1);
			}
		} catch(IOException e) {
			if(ftp.isConnected()) {
				try {
					ftp.disconnect();
				} catch(IOException f) {
					// do nothing
				}
			}
			System.err.println("Could not connect to server.");
			e.printStackTrace();
			System.exit(1);
		}

		__main:
		try {
			if(!ftp.login(username, password)) {
				ftp.logout();
				break __main;
			}
			System.out.println("Remote system is " + ftp.getSystemName());

			InputStream input;
			input = new FileInputStream(local);
			ftp.storeFile(remote, input);

			InputStream input2;
			input2 = new FileInputStream(System.getProperty("user.dir") + "/rss.xml");
			ftp.storeFile(destination.getRemoteRSS(), input2);

			ftp.logout();
		} catch(FTPConnectionClosedException e) {
			System.err.println("Server closed connection.");
			e.printStackTrace();
		} catch(IOException e) {
			e.printStackTrace();
		} finally {

			if(ftp.isConnected()) {
				try {
					ftp.disconnect();
				} catch(IOException f) {
					// do nothing
				}
			}
		}
	}
}